==> v-sim_3.3.3.orig.tar.gz: v_sim-3.3.3/src/panelModules/panelFogBgColor.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef PANELFOGBGCOLOR_H
#define PANELFOGBGCOLOR_H

#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>

#include <visu_tools.h>
#include <extensions/fogAndBGColor.h>

/* Sensitive widget in this subpanel. */
GtkWidget *checkFogIsOn;
GtkWidget *rangeFogStart, *rangeFogEnd;
GtkWidget *radioBgFog, *radioOtherFog;
GtkWidget *rgbBgColor[3];
GtkWidget *rgbFogColor[3];


/* Private functions. */
GtkWidget *createInteriorFogBgColor();
void createCallBacksFogBgColor();

/* callbacks */
void fogCheckChanged(GtkToggleButton *button, gpointer data);
void changedRGBBgColor(GtkRange *rg, gpointer data);
void radioBgChanged(GtkToggleButton *button, gpointer data);
void changedRGBFogColor(GtkRange *rg, gpointer data);
void changedFogStart(GtkRange *rg, gpointer data);
void changedFogEnd(GtkRange *rg, gpointer data);

#endif

==> v-sim_3.6.0.orig.tar.gz: v_sim-3.6.0/src/panelModules/panelFogBgColor.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef PANELFOGBGCOLOR_H
#define PANELFOGBGCOLOR_H

#include <extraGtkFunctions/gtk_toolPanelWidget.h>

/**
 * panelFogBgColor_init:
 *
 * Should be used in the list declared in externalModules.h to be loaded by
 * V_Sim on start-up. This routine will create the #ToolPanel where the fog
 * and the background colour stuff can be tuned, such the position of
 * the fog, its colour...
 *
 * Returns: a newly created #ToolPanel object.
 */
ToolPanel* panelFogBgColor_init();

/**
 * panelFogBgColorSet_bgImage:
 * @filename: a path to a file.
 *
 * Set the background image.
 */
void panelFogBgColorSet_bgImage(const gchar *filename);

#endif
